summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
-rw-r--r--haunt.scm7
1 files changed, 4 insertions, 3 deletions
diff --git a/haunt.scm b/haunt.scm
index b2dd1e0..f3522f5 100644
--- a/haunt.scm
+++ b/haunt.scm
@@ -143,7 +143,8 @@ FILTER: The procedure called to manipulate the posts list before rendering"
(lambda (site posts)
(define (tag-list tag posts all-posts)
(define (render-list title posts prefix)
- (let ((body ((theme-list-template theme) site title posts prefix all-posts tag)))
+ (let ((body ((theme-collection-template theme)
+ site title posts prefix all-posts tag)))
((theme-layout theme) site title body)))
(make-page (string-append "tags/" tag ".html")
(render-list (string-append "Posts tagged ‘" tag "’")
@@ -216,7 +217,7 @@ in parentheses."
#:layout default-layout
#:post-template ; TODO: should also take "site" for "site-post-slug"
(lambda (post)
;; TODO: similar version below for list-template
(define (post-uri post)
(string-append "/posts/" (%make-slug post) ".html"))
`((h1 (@ (class "donthyphenate")) ,(post-ref post 'title))
@@ -233,7 +234,7 @@ in parentheses."
(div (@ (id "disqus_thread")))
(a (@ (id "loadComments") (href "javascript:loadComments()"))
"Click to load Disqus comments")))
- #:list-template
+ #:collection-template
(lambda* (site title posts prefix #:optional all-posts tag)
(define (post-uri post)
(string-append "/" (or prefix "") (site-post-slug site post) ".html"))
@@ -216,7 +217,7 @@ in parentheses."
#:post-template ; TODO: should also take "site" for "site-post-slug"
(lambda (post)
- ;; TODO: similar version below for list-template
+ ;; TODO: similar version below for collection-template
(define (post-uri post)
(string-append "/posts/" (%make-slug post) ".html"))